:html_theme.sidebar_secondary.remove: true
:html_theme.sidebar_primary.remove: true

.. _radiotools:

##########################################
Tools for Radio Astronomy (``radiotools``)
##########################################

.. currentmodule:: radiotools


**Version**: |version| **Date**: |today|

**Useful links**:
`Source Repository <https://github.com/radionets-project/radiotools>`__ |
`Issue Tracker <https://github.com/radionets-project/radiotools/issues>`__ |
`Pull Requests <https://github.com/radionets-project/radiotools/pulls>`__

**License**: MIT

**Python**: |python_requires|


.. _radiotools_docs:

.. toctree::
  :maxdepth: 1
  :hidden:

  user-guide/index
  developer-guide/index
  api-reference/index
  changelog


.. grid:: 1 2 2 3

    .. grid-item-card::
        :class-item: animated-sd-card

        :octicon:`book;40px`

        User Guide
        ^^^^^^^^^^

        Learn how to get started as a user. This guide
        will help you install radiotools.

        +++

        .. button-ref:: user-guide/index
            :expand:
            :color: primary
            :click-parent:

            To the user guide


    .. grid-item-card::
        :class-item: animated-sd-card

        :octicon:`person-add;40px`

        Developer Guide
        ^^^^^^^^^^^^^^^

        Learn how to get started as a developer.
        This guide will help you install radiotools
        for development and explains how to contribute.

        +++

        .. button-ref:: developer-guide/index
            :expand:
            :color: primary
            :click-parent:

            To the developer guide


    .. grid-item-card::
        :class-item: animated-sd-card

        :octicon:`code;40px`

        API Reference
        ^^^^^^^^^^^^^

        The API reference contains detailed
        descriptions of of the modules, classes
        and functions included in radiotools.

        +++

        .. button-ref:: api-reference/index
            :expand:
            :color: primary
            :click-parent:

            To the API reference
